flutter_radar library
Classes
- Radar
- RadarBackgroundEvent
- An event delivered to the durable Radar background handler.
- RadarInitializeOptions
Enums
- RadarBackgroundEventType
- The Radar callback represented by a RadarBackgroundEvent.
Typedefs
- ClientLocationCallback = void Function(Map locationEvent)
- ErrorCallback = void Function(Map locationEvent)
- EventsCallback = void Function(Map locationEvent)
- IpChangedCallback = void Function()
- LocationCallback = void Function(Map locationEvent)
- LogCallback = void Function(Map locationEvent)
-
RadarBackgroundHandler
= Future<
void> Function(RadarBackgroundEvent event) - A durable Radar event handler that can run in a primary or headless isolate.
- SharingChangedCallback = void Function(bool sharing)
- TokenCallback = void Function(Map locationEvent)